searchData={"items":[{"type":"module","title":"Bcrypt","doc":"Elixir wrapper for the Bcrypt password hashing function.\n\nFor a lower-level API, see `Bcrypt.Base`.","ref":"Bcrypt.html"},{"type":"module","title":"Configuration - Bcrypt","doc":"The following parameter can be set in the config file:\n\n  * `:log_rounds` - the computational cost as number of log rounds\n    * the default is `12` (2^12 rounds)\n\nIf you are hashing passwords in your tests, it can be useful to add\nthe following to the `config/test.exs` file:\n\n    # Note: Do not use this value in production\n    config :bcrypt_elixir, log_rounds: 4","ref":"Bcrypt.html#module-configuration"},{"type":"module","title":"Bcrypt - Bcrypt","doc":"Bcrypt is a key derivation function for passwords designed by Niels Provos\nand David Mazières. Bcrypt is an adaptive function, which means that it can\nbe configured to remain slow and resistant to brute-force attacks even as\ncomputational power increases.","ref":"Bcrypt.html#module-bcrypt"},{"type":"module","title":"Bcrypt versions - Bcrypt","doc":"This bcrypt implementation is based on the latest OpenBSD version, which\nfixed a small issue that affected some passwords longer than 72 characters.\nBy default, it produces hashes with the prefix `$2b$`, and it can check\nhashes with either the `$2b$` prefix or the older `$2a$` prefix.\nIt is also possible to generate hashes with the `$2a$` prefix by running\nthe following command:\n\n    Bcrypt.Base.hash_password(\"hard to guess\", Bcrypt.Base.gen_salt(12, true))\n\nThis option should only be used if you need to generate hashes that are\nthen checked by older libraries.\n\nThe `$2y$` prefix is not supported. For advice on how to use hashes with the\n`$2y$` prefix, see [this issue](https://github.com/riverrun/comeonin/issues/103).\nHash the password with a salt which is randomly generated.","ref":"Bcrypt.html#module-bcrypt-versions"},{"type":"function","title":"Bcrypt.hash_pwd_salt/2","doc":"Hashes a password with a randomly generated salt.","ref":"Bcrypt.html#hash_pwd_salt/2"},{"type":"function","title":"Option - Bcrypt.hash_pwd_salt/2","doc":"* `:log_rounds` - the computational cost as number of log rounds\n    * the default is 12 (2^12 rounds)\n    * this can be used to override the value set in the config","ref":"Bcrypt.html#hash_pwd_salt/2-option"},{"type":"function","title":"Examples - Bcrypt.hash_pwd_salt/2","doc":"The following examples show how to hash a password with a randomly-generated\nsalt and then verify a password:\n\n    iex> hash = Bcrypt.hash_pwd_salt(\"password\")\n    ...> Bcrypt.verify_pass(\"password\", hash)\n    true\n\n    iex> hash = Bcrypt.hash_pwd_salt(\"password\")\n    ...> Bcrypt.verify_pass(\"incorrect\", hash)\n    false","ref":"Bcrypt.html#hash_pwd_salt/2-examples"},{"type":"function","title":"Bcrypt.no_user_verify/1","doc":"Runs the password hash function, but always returns false.\n\nThis function is intended to make it more difficult for any potential\nattacker to find valid usernames by using timing attacks. This function\nis only useful if it is used as part of a policy of hiding usernames.\n\nThere are concerns about this function using too many resources (CPU and\nmemory). An alternative approach is to create a function that adds a sleep\ncalculated to make the time spent running the function the same as if the\nhash function was run.","ref":"Bcrypt.html#no_user_verify/1"},{"type":"function","title":"Options - Bcrypt.no_user_verify/1","doc":"This function should be called with the same options as those used by\n`hash_pwd_salt/2`.","ref":"Bcrypt.html#no_user_verify/1-options"},{"type":"function","title":"Bcrypt.verify_pass/2","doc":"Verifies a password by hashing the password and comparing the hashed value\nwith a stored hash.\n\nSee the documentation for `hash_pwd_salt/2` for examples of using this function.","ref":"Bcrypt.html#verify_pass/2"},{"type":"module","title":"Bcrypt.Base","doc":"Base module for the Bcrypt password hashing library.","ref":"Bcrypt.Base.html"},{"type":"function","title":"Bcrypt.Base.checkpass_nif/2","doc":"Verify the password by comparing it with the stored hash.","ref":"Bcrypt.Base.html#checkpass_nif/2"},{"type":"function","title":"Bcrypt.Base.gen_salt/2","doc":"Generate a salt for use with the `hash_password` function.\n\nThe `:log_rounds` parameter determines the computational complexity\nof the generation of the password hash. Its default is 12, the minimum is 4,\nand the maximum is 31.\n\nThe `:legacy` option is for generating salts with the old `$2a$` prefix.\nOnly use this option if you need to generate hashes that are then checked\nby older libraries.","ref":"Bcrypt.Base.html#gen_salt/2"},{"type":"function","title":"Bcrypt.Base.gensalt_nif/3","doc":"Generate a salt for use with Bcrypt.","ref":"Bcrypt.Base.html#gensalt_nif/3"},{"type":"function","title":"Bcrypt.Base.hash_nif/2","doc":"Hash the password and salt with the Bcrypt hashing algorithm.","ref":"Bcrypt.Base.html#hash_nif/2"},{"type":"function","title":"Bcrypt.Base.hash_password/2","doc":"Hash a password using Bcrypt.","ref":"Bcrypt.Base.html#hash_password/2"},{"type":"function","title":"Bcrypt.Base.init/0","doc":"","ref":"Bcrypt.Base.html#init/0"},{"type":"module","title":"Bcrypt.Stats","doc":"Module to provide statistics for the Bcrypt password hashing function.\n\nThe `report/1` function in this module can be used to help you configure\nBcrypt.","ref":"Bcrypt.Stats.html"},{"type":"module","title":"Configuration - Bcrypt.Stats","doc":"There is one configuration option for Bcrypt - `:log_rounds`.\nIncreasing this value will increase the complexity, and time\ntaken, of the Bcrypt function.\n\nIncreasing the time that a password hash function takes makes it more\ndifficult for an attacker to find the correct password. However, the\namount of time a valid user has to wait also needs to be taken into\nconsideration when setting the number of log rounds.\n\nThe correct number of log rounds depends on circumstances specific to your\nuse case, such as what level of security you want, how often the user\nhas to log in, and the hardware you are using. However, for password\nhashing, we do not recommend setting the number of log rounds to anything\nless than 12.","ref":"Bcrypt.Stats.html#module-configuration"},{"type":"function","title":"Bcrypt.Stats.report/1","doc":"Hash a password with Bcrypt and print out a report.\n\nThis function hashes a password, and salt, with `Bcrypt.Base.hash_password/2`\nand prints out statistics which can help you choose how many to configure\nBcrypt.","ref":"Bcrypt.Stats.html#report/1"},{"type":"function","title":"Options - Bcrypt.Stats.report/1","doc":"There are three options:\n\n  * `:log_rounds` - the number of log rounds\n    * the default is 12\n  * `:password` - the password used\n    * the default is \"password\"\n  * `:salt` - the salt used\n    * the default is the output of `Bcrypt.Base.gen_salt`","ref":"Bcrypt.Stats.html#report/1-options"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v3.2.0 (2024-10-04) - Changelog","doc":"* Changes\n  * Updated dependencies and made changes to silence warnings in Elixir 1.17","ref":"changelog.html#v3-2-0-2024-10-04"},{"type":"extras","title":"v3.1.0 (2023-08-26) - Changelog","doc":"* Changes\n  * Updated dependencies and documentation (through updates to the Comeonin documentation)","ref":"changelog.html#v3-1-0-2023-08-26"},{"type":"extras","title":"v3.0.0 (2022-01-20) - Changelog","doc":"* Changes\n  * moved `gen_salt` to the `Base` module","ref":"changelog.html#v3-0-0-2022-01-20"},{"type":"extras","title":"v2.3.1 (2022-01-19) - Changelog","doc":"* Changes\n  * Updated documentation","ref":"changelog.html#v2-3-1-2022-01-19"},{"type":"extras","title":"v2.3.0 (2021-01-07) - Changelog","doc":"* Enhancements\n  * Updated Makefile to be more robust, especially for Nerves users","ref":"changelog.html#v2-3-0-2021-01-07"},{"type":"extras","title":"v2.2.0 (2020-03-01) - Changelog","doc":"* Changes\n  * Using Comeonin v5.3, which changes `add_hash` so that it does NOT set the password to nil","ref":"changelog.html#v2-2-0-2020-03-01"},{"type":"extras","title":"v2.1.0 (2020-01-20) - Changelog","doc":"* Enhancements\n  * Updated documentation - in line with updates to Comeonin v5.2","ref":"changelog.html#v2-1-0-2020-01-20"},{"type":"extras","title":"v2.0.0 (2019-02-12) - Changelog","doc":"* Enhancements\n  * Updated to use the Comeonin and Comeonin.PasswordHash behaviours (Comeonin v5.0)","ref":"changelog.html#v2-0-0-2019-02-12"},{"type":"extras","title":"v1.0.0 (2019-01-17) - Changelog","doc":"* Enhancements\n  * Updated C NIF code to use dirty schedulers","ref":"changelog.html#v1-0-0-2019-01-17"},{"type":"extras","title":"v0.12.0 (2017-08-06) - Changelog","doc":"* Changes\n  * Created separate Bcrypt library","ref":"changelog.html#v0-12-0-2017-08-06"},{"type":"extras","title":"Bcrypt","doc":"# Bcrypt\n\n[![Build Status](https://travis-ci.com/riverrun/bcrypt_elixir.svg?branch=master)](https://travis-ci.com/riverrun/bcrypt_elixir)\n[![Module Version](http://img.shields.io/hexpm/v/bcrypt_elixir.svg)](https://hex.pm/packages/bcrypt_elixir)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg)](https://hexdocs.pm/bcrypt_elixir/)\n[![Total Download](https://img.shields.io/hexpm/dt/bcrypt_elixir.svg)](https://hex.pm/packages/bcrypt_elixir)\n[![License](https://img.shields.io/hexpm/l/bcrypt_elixir.svg)](https://github.com/riverrun/bcrypt_elixir/blob/master/LICENSE)\n[![Last Updated](https://img.shields.io/github/last-commit/riverrun/bcrypt_elixir.svg)](https://github.com/riverrun/bcrypt_elixir/commits/master)\n\nBcrypt password hashing library for Elixir.\n\nBcrypt is a well-tested password-based key derivation function that\ncan be configured to remain slow and resistant to brute-force attacks\neven as computational power increases.","ref":"readme.html"},{"type":"extras","title":"Compatibility with other Bcrypt libraries - Bcrypt","doc":"This version is based on the OpenBSD version of Bcrypt and supports\nthe `$2b$` and `$2a$` prefixes. For advice on how to use hashes with\nthe `$2y$` prefix, see [this issue](https://github.com/riverrun/comeonin/issues/103).","ref":"readme.html#compatibility-with-other-bcrypt-libraries"},{"type":"extras","title":"Installation - Bcrypt","doc":"1.  Add `:bcrypt_elixir` to the `deps` section of your `mix.exs` file:\n\n    If you are using Erlang >20:\n\n    ```elixir\n    def deps do\n      [\n        {:bcrypt_elixir, \"~> 3.0\"}\n      ]\n    end\n    ```\n\n    If you are using Erlang 19 or below:\n\n    ```elixir\n    def deps do\n      [\n        {:bcrypt_elixir, \"~> 0.12\"}\n      ]\n    end\n    ```\n\n2.  Make sure you have a C compiler installed.\nSee the [Comeonin wiki](https://github.com/riverrun/comeonin/wiki/Requirements) for details.\n\n3.  Optional: during tests (and tests only), you may want to reduce the number of rounds\nso it does not slow down your test suite. If you have a config/test.exs, you should\nadd:\n\n    ```elixir\n    config :bcrypt_elixir, :log_rounds, 4\n    ```","ref":"readme.html#installation"},{"type":"extras","title":"Comeonin wiki - Bcrypt","doc":"See the [Comeonin wiki](https://github.com/riverrun/comeonin/wiki) for more\ninformation on the following topics:\n\n* [Algorithms](https://github.com/riverrun/comeonin/wiki/Choosing-the-password-hashing-algorithm)\n* [Requirements](https://github.com/riverrun/comeonin/wiki/Requirements)\n* [Deployment](https://github.com/riverrun/comeonin/wiki/Deployment)\n  * Including information about using Docker\n* [References](https://github.com/riverrun/comeonin/wiki/References)","ref":"readme.html#comeonin-wiki"},{"type":"extras","title":"Contributing - Bcrypt","doc":"There are many ways you can contribute to the development of this library, including:\n\n* Reporting issues\n* Improving documentation\n* Sharing your experiences with others","ref":"readme.html#contributing"},{"type":"extras","title":"Documentation - Bcrypt","doc":"http://hexdocs.pm/bcrypt_elixir","ref":"readme.html#documentation"},{"type":"extras","title":"License - Bcrypt","doc":"BSD. For full details, please read the LICENSE file.","ref":"readme.html#license"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}